summaryrefslogtreecommitdiffstats
path: root/kmail/encodingdetector.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/encodingdetector.cpp')
-rw-r--r--kmail/encodingdetector.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/encodingdetector.cpp b/kmail/encodingdetector.cpp
index cc19e3b1..06537981 100644
--- a/kmail/encodingdetector.cpp
+++ b/kmail/encodingdetector.cpp
@@ -51,7 +51,7 @@
// Multiple scripts per language were removed and the entries were reordered so
// that simple substring matching will work. For example, bam was put before ba
// so that the first match will be likely the right match. Otherwise "ba" would
// match "bam" but we would have to search on to tqfind "bam" which is what we want.
// The original file is called pango-script-lang-table.h
/* pango-script-lang-table.h:
@@ -824,7 +824,7 @@ EncodingDetector::EncodingChoiceSource EncodingDetector::encodingChoiceSource()
const char* EncodingDetector::encoding() const
{
d->m_storeDecoderName = d->m_codec->name();
- d->m_storeDecoderName = d->m_storeDecoderName.lower().tqreplace( "iso ", "iso-" );
+ d->m_storeDecoderName = d->m_storeDecoderName.lower().replace( "iso ", "iso-" );
return d->m_storeDecoderName.data();
}
@@ -1059,13 +1059,13 @@ bool EncodingDetector::analyze(const char *data, int len)
TQCString str( ptr, (end-ptr)+1);
str = str.lower();
int pos=0;
- //if( (pos = str.tqfind("http-equiv", pos)) == -1) break;
- //if( (pos = str.tqfind("content-type", pos)) == -1) break;
- if( (pos = str.tqfind("charset")) == -1)
+ //if( (pos = str.find("http-equiv", pos)) == -1) break;
+ //if( (pos = str.find("content-type", pos)) == -1) break;
+ if( (pos = str.find("charset")) == -1)
continue;
pos+=6;
// skip to '='
- if( (pos = str.tqfind('=', pos)) == -1)
+ if( (pos = str.find('=', pos)) == -1)
continue;
// skip whitespace before encoding itself
@@ -51,7 +51,7 @@
// that simple substring matching will work. For example, bam was put before ba
// so that the first match will be likely the right match. Otherwise "ba" would
-// match "bam" but we would have to search on to tqfind "bam" which is what we want.
+// match "bam" but we would have to search on to find "bam" which is what we want.
// The original file is called pango-script-lang-table.h
/* pango-script-lang-table.h: